# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.10.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.scim_provider_request import SCIMProviderRequest

class TestSCIMProviderRequest(unittest.TestCase):
    """SCIMProviderRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SCIMProviderRequest:
        """Test SCIMProviderRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SCIMProviderRequest`
        """
        model = SCIMProviderRequest()
        if include_optional:
            return SCIMProviderRequest(
                name = '0',
                property_mappings = [
                    ''
                    ],
                property_mappings_group = [
                    ''
                    ],
                url = '0',
                verify_certificates = True,
                token = '',
                auth_mode = 'token',
                auth_oauth = '',
                auth_oauth_params = {
                    'key' : null
                    },
                compatibility_mode = 'default',
                exclude_users_service_account = True,
                filter_group = '',
                dry_run = True
            )
        else:
            return SCIMProviderRequest(
                name = '0',
                url = '0',
        )
        """

    def testSCIMProviderRequest(self):
        """Test SCIMProviderRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
